@@ -373,13 +373,14 @@ setup(
         # these should get autoinstalled
         self._mksrc('bin/yell', '#!/bin/sh', True)
         self._mksrc('bin/shout', '#!/bin/sh', True)
-        self._mksrc('bin/foo', '#!/bin/sh', True)
+        self._mksrc('bin/foo', b'#!/usr/bin/python\n# \xc2\xa9 copyright'.decode('UTF-8'), True)
         os.symlink('shout', os.path.join(self.src, 'bin', 'shoutlink'))
 
         # these shouldn't
         self._mksrc('daemon/food', '#!/bin/sh', True) # not in bin/
         self._mksrc('foob', '#!/bin/sh', True) # not named like project
-        self._mksrc('bin/whisper', '#!/bin/sh') # not executable
+        # not executable
+        self._mksrc('bin/whisper', b'#!/usr/bin/python\n# \xc2\xa9 copyright'.decode('UTF-8'))
 
         (o, e, s) = self.do_install()
         self.assertEqual(e, '')
@@ -814,7 +815,26 @@ print ('import iamnota.module')
         f = self.installed_files()
         self.assertEqual(len(f), 1, f)
         self.assertTrue('egg-info' in f[0])
+
+    def test_utf8_filenames(self):
+        '''UTF-8 file names'''
             
+        bin_fname = b'a\xc3\xa4b.bin'.decode('UTF-8')
+        with open(os.path.join(self.src, bin_fname).encode('UTF-8'), 'wb') as f:
+            f.write(b'\x00\x01abc\xFF\xFE')
+
+        (o, e, s) = self.do_install()
+        self.assertEqual(e, '')
+        self.assertEqual(s, 0)
+
+        f = self.installed_files()
+        self.assertEqual(len(f), 1, f)
+        self.assertTrue('egg-info' in f[0])
+
+        self.assertTrue('following files are not recognized' in o)
+        # this might not be the correct file name when the locale is e. g. C
+        self.assertTrue('b.bin\n' in o, o)
+
     #
     # helper methods
     #
